/****************************************************************************
** Meta object code from reading C++ file 'sessionstack.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../yakuake-26.08.0/app/sessionstack.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionstack.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12SessionStackE_t {};
} // unnamed namespace

template <> constexpr inline auto SessionStack::qt_create_metaobjectdata<qt_meta_tag_ZN12SessionStackE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SessionStack",
        "D-Bus Interface",
        "org.kde.yakuake",
        "sessionAdded",
        "",
        "sessionId",
        "title",
        "sessionRaised",
        "sessionRemoved",
        "activeTitleChanged",
        "titleChanged",
        "closeTerminal",
        "previousTerminal",
        "nextTerminal",
        "manageProfiles",
        "removeTerminalHighlight",
        "wantsBlurChanged",
        "addSessionImpl",
        "Session::SessionType",
        "type",
        "addSession",
        "addSessionTwoHorizontal",
        "addSessionTwoVertical",
        "addSessionQuad",
        "raiseSession",
        "removeSession",
        "removeTerminal",
        "terminalId",
        "splitSessionAuto",
        "splitSessionLeftRight",
        "splitSessionTopBottom",
        "splitTerminalLeftRight",
        "splitTerminalTopBottom",
        "tryGrowTerminalRight",
        "pixels",
        "tryGrowTerminalLeft",
        "tryGrowTerminalTop",
        "tryGrowTerminalBottom",
        "activeSessionId",
        "activeTerminalId",
        "sessionIdList",
        "terminalIdList",
        "terminalIdsForSessionId",
        "sessionIdForTerminalId",
        "runCommand",
        "command",
        "runCommandInTerminal",
        "isSessionClosable",
        "setSessionClosable",
        "closable",
        "hasUnclosableSessions",
        "isSessionKeyboardInputEnabled",
        "setSessionKeyboardInputEnabled",
        "enabled",
        "isTerminalKeyboardInputEnabled",
        "setTerminalKeyboardInputEnabled",
        "hasTerminalsWithKeyboardInputEnabled",
        "hasTerminalsWithKeyboardInputDisabled",
        "isSessionMonitorActivityEnabled",
        "setSessionMonitorActivityEnabled",
        "isTerminalMonitorActivityEnabled",
        "setTerminalMonitorActivityEnabled",
        "hasTerminalsWithMonitorActivityEnabled",
        "hasTerminalsWithMonitorActivityDisabled",
        "isSessionMonitorSilenceEnabled",
        "setSessionMonitorSilenceEnabled",
        "isTerminalMonitorSilenceEnabled",
        "setTerminalMonitorSilenceEnabled",
        "hasTerminalsWithMonitorSilenceEnabled",
        "hasTerminalsWithMonitorSilenceDisabled",
        "handleTerminalHighlightRequest",
        "handleManualTerminalActivation",
        "Terminal*",
        "cleanup"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sessionAdded'
        QtMocHelpers::SignalData<void(int, const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'sessionRaised'
        QtMocHelpers::SignalData<void(int)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'sessionRemoved'
        QtMocHelpers::SignalData<void(int)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'activeTitleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(int, const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'closeTerminal'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previousTerminal'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextTerminal'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'manageProfiles'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'removeTerminalHighlight'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wantsBlurChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addSessionImpl'
        QtMocHelpers::SlotData<int(Session::SessionType)>(17, 4, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'addSessionImpl'
        QtMocHelpers::SlotData<int()>(17, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Slot 'addSession'
        QtMocHelpers::SlotData<int()>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'addSessionTwoHorizontal'
        QtMocHelpers::SlotData<int()>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'addSessionTwoVertical'
        QtMocHelpers::SlotData<int()>(22, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'addSessionQuad'
        QtMocHelpers::SlotData<int()>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'raiseSession'
        QtMocHelpers::SlotData<void(int)>(24, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'removeSession'
        QtMocHelpers::SlotData<void(int)>(25, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'removeTerminal'
        QtMocHelpers::SlotData<void(int)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'splitSessionAuto'
        QtMocHelpers::SlotData<int(int)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'splitSessionLeftRight'
        QtMocHelpers::SlotData<int(int)>(29, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'splitSessionTopBottom'
        QtMocHelpers::SlotData<int(int)>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'splitTerminalLeftRight'
        QtMocHelpers::SlotData<int(int)>(31, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'splitTerminalTopBottom'
        QtMocHelpers::SlotData<int(int)>(32, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'tryGrowTerminalRight'
        QtMocHelpers::SlotData<int(int, uint)>(33, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 }, { QMetaType::UInt, 34 },
        }}),
        // Slot 'tryGrowTerminalRight'
        QtMocHelpers::SlotData<int(int)>(33, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'tryGrowTerminalLeft'
        QtMocHelpers::SlotData<int(int, uint)>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 }, { QMetaType::UInt, 34 },
        }}),
        // Slot 'tryGrowTerminalLeft'
        QtMocHelpers::SlotData<int(int)>(35, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'tryGrowTerminalTop'
        QtMocHelpers::SlotData<int(int, uint)>(36, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 }, { QMetaType::UInt, 34 },
        }}),
        // Slot 'tryGrowTerminalTop'
        QtMocHelpers::SlotData<int(int)>(36, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'tryGrowTerminalBottom'
        QtMocHelpers::SlotData<int(int, uint)>(37, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 }, { QMetaType::UInt, 34 },
        }}),
        // Slot 'tryGrowTerminalBottom'
        QtMocHelpers::SlotData<int(int)>(37, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'activeSessionId'
        QtMocHelpers::SlotData<int()>(38, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'activeTerminalId'
        QtMocHelpers::SlotData<int()>(39, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'sessionIdList'
        QtMocHelpers::SlotData<const QString()>(40, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'terminalIdList'
        QtMocHelpers::SlotData<const QString()>(41, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'terminalIdsForSessionId'
        QtMocHelpers::SlotData<const QString(int)>(42, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'sessionIdForTerminalId'
        QtMocHelpers::SlotData<int(int)>(43, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'runCommand'
        QtMocHelpers::SlotData<void(const QString &)>(44, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 45 },
        }}),
        // Slot 'runCommandInTerminal'
        QtMocHelpers::SlotData<void(int, const QString &)>(46, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::QString, 45 },
        }}),
        // Slot 'isSessionClosable'
        QtMocHelpers::SlotData<bool(int)>(47, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setSessionClosable'
        QtMocHelpers::SlotData<void(int, bool)>(48, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Bool, 49 },
        }}),
        // Slot 'hasUnclosableSessions'
        QtMocHelpers::SlotData<bool() const>(50, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'isSessionKeyboardInputEnabled'
        QtMocHelpers::SlotData<bool(int)>(51, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setSessionKeyboardInputEnabled'
        QtMocHelpers::SlotData<void(int, bool)>(52, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'isTerminalKeyboardInputEnabled'
        QtMocHelpers::SlotData<bool(int)>(54, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setTerminalKeyboardInputEnabled'
        QtMocHelpers::SlotData<void(int, bool)>(55, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'hasTerminalsWithKeyboardInputEnabled'
        QtMocHelpers::SlotData<bool(int)>(56, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'hasTerminalsWithKeyboardInputDisabled'
        QtMocHelpers::SlotData<bool(int)>(57, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'isSessionMonitorActivityEnabled'
        QtMocHelpers::SlotData<bool(int)>(58, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setSessionMonitorActivityEnabled'
        QtMocHelpers::SlotData<void(int, bool)>(59, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'isTerminalMonitorActivityEnabled'
        QtMocHelpers::SlotData<bool(int)>(60, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setTerminalMonitorActivityEnabled'
        QtMocHelpers::SlotData<void(int, bool)>(61, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'hasTerminalsWithMonitorActivityEnabled'
        QtMocHelpers::SlotData<bool(int)>(62, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'hasTerminalsWithMonitorActivityDisabled'
        QtMocHelpers::SlotData<bool(int)>(63, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'isSessionMonitorSilenceEnabled'
        QtMocHelpers::SlotData<bool(int)>(64, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setSessionMonitorSilenceEnabled'
        QtMocHelpers::SlotData<void(int, bool)>(65, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'isTerminalMonitorSilenceEnabled'
        QtMocHelpers::SlotData<bool(int)>(66, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setTerminalMonitorSilenceEnabled'
        QtMocHelpers::SlotData<void(int, bool)>(67, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'hasTerminalsWithMonitorSilenceEnabled'
        QtMocHelpers::SlotData<bool(int)>(68, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'hasTerminalsWithMonitorSilenceDisabled'
        QtMocHelpers::SlotData<bool(int)>(69, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'handleTerminalHighlightRequest'
        QtMocHelpers::SlotData<void(int)>(70, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'handleManualTerminalActivation'
        QtMocHelpers::SlotData<void(Terminal *)>(71, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 72, 4 },
        }}),
        // Slot 'cleanup'
        QtMocHelpers::SlotData<void(int)>(73, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SessionStack, qt_meta_tag_ZN12SessionStackE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SessionStack::staticMetaObject = { {
    QMetaObject::SuperData::link<QStackedWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SessionStackE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SessionStackE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12SessionStackE_t>.metaTypes,
    nullptr
} };

void SessionStack::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SessionStack *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sessionAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->sessionRaised((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->sessionRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->activeTitleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->closeTerminal(); break;
        case 6: _t->previousTerminal(); break;
        case 7: _t->nextTerminal(); break;
        case 8: _t->manageProfiles(); break;
        case 9: _t->removeTerminalHighlight(); break;
        case 10: _t->wantsBlurChanged(); break;
        case 11: { int _r = _t->addSessionImpl((*reinterpret_cast<std::add_pointer_t<Session::SessionType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: { int _r = _t->addSessionImpl();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: { int _r = _t->addSession();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->addSessionTwoHorizontal();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: { int _r = _t->addSessionTwoVertical();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 16: { int _r = _t->addSessionQuad();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->raiseSession((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->removeSession((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->removeTerminal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: { int _r = _t->splitSessionAuto((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 21: { int _r = _t->splitSessionLeftRight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 22: { int _r = _t->splitSessionTopBottom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 23: { int _r = _t->splitTerminalLeftRight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 24: { int _r = _t->splitTerminalTopBottom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 25: { int _r = _t->tryGrowTerminalRight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 26: { int _r = _t->tryGrowTerminalRight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 27: { int _r = _t->tryGrowTerminalLeft((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 28: { int _r = _t->tryGrowTerminalLeft((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 29: { int _r = _t->tryGrowTerminalTop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 30: { int _r = _t->tryGrowTerminalTop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 31: { int _r = _t->tryGrowTerminalBottom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 32: { int _r = _t->tryGrowTerminalBottom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 33: { int _r = _t->activeSessionId();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 34: { int _r = _t->activeTerminalId();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 35: { QString _r = _t->sessionIdList();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 36: { QString _r = _t->terminalIdList();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 37: { QString _r = _t->terminalIdsForSessionId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 38: { int _r = _t->sessionIdForTerminalId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->runCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: _t->runCommandInTerminal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 41: { bool _r = _t->isSessionClosable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->setSessionClosable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 43: { bool _r = _t->hasUnclosableSessions();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 44: { bool _r = _t->isSessionKeyboardInputEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 45: _t->setSessionKeyboardInputEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 46: { bool _r = _t->isTerminalKeyboardInputEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->setTerminalKeyboardInputEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 48: { bool _r = _t->hasTerminalsWithKeyboardInputEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 49: { bool _r = _t->hasTerminalsWithKeyboardInputDisabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 50: { bool _r = _t->isSessionMonitorActivityEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 51: _t->setSessionMonitorActivityEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 52: { bool _r = _t->isTerminalMonitorActivityEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->setTerminalMonitorActivityEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 54: { bool _r = _t->hasTerminalsWithMonitorActivityEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 55: { bool _r = _t->hasTerminalsWithMonitorActivityDisabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 56: { bool _r = _t->isSessionMonitorSilenceEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 57: _t->setSessionMonitorSilenceEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 58: { bool _r = _t->isTerminalMonitorSilenceEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 59: _t->setTerminalMonitorSilenceEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 60: { bool _r = _t->hasTerminalsWithMonitorSilenceEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 61: { bool _r = _t->hasTerminalsWithMonitorSilenceDisabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 62: _t->handleTerminalHighlightRequest((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 63: _t->handleManualTerminalActivation((*reinterpret_cast<std::add_pointer_t<Terminal*>>(_a[1]))); break;
        case 64: _t->cleanup((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SessionStack::*)(int , const QString & )>(_a, &SessionStack::sessionAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStack::*)(int )>(_a, &SessionStack::sessionRaised, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStack::*)(int )>(_a, &SessionStack::sessionRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStack::*)(const QString & )>(_a, &SessionStack::activeTitleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStack::*)(int , const QString & )>(_a, &SessionStack::titleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStack::*)()>(_a, &SessionStack::closeTerminal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStack::*)()>(_a, &SessionStack::previousTerminal, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStack::*)()>(_a, &SessionStack::nextTerminal, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStack::*)()>(_a, &SessionStack::manageProfiles, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStack::*)()>(_a, &SessionStack::removeTerminalHighlight, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SessionStack::*)()>(_a, &SessionStack::wantsBlurChanged, 10))
            return;
    }
}

const QMetaObject *SessionStack::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SessionStack::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SessionStackE_t>.strings))
        return static_cast<void*>(this);
    return QStackedWidget::qt_metacast(_clname);
}

int SessionStack::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStackedWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 65)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 65;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 65)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 65;
    }
    return _id;
}

// SIGNAL 0
void SessionStack::sessionAdded(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void SessionStack::sessionRaised(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SessionStack::sessionRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SessionStack::activeTitleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SessionStack::titleChanged(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void SessionStack::closeTerminal()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SessionStack::previousTerminal()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SessionStack::nextTerminal()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void SessionStack::manageProfiles()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void SessionStack::removeTerminalHighlight()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void SessionStack::wantsBlurChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
